cosmic\_ray.operators package
=============================

Submodules
----------

cosmic\_ray.operators.binary\_operator\_replacement module
----------------------------------------------------------

.. automodule:: cosmic_ray.operators.binary_operator_replacement
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.boolean\_replacer module
----------------------------------------------

.. automodule:: cosmic_ray.operators.boolean_replacer
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.break\_continue module
--------------------------------------------

.. automodule:: cosmic_ray.operators.break_continue
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.comparison\_operator\_replacement module
--------------------------------------------------------------

.. automodule:: cosmic_ray.operators.comparison_operator_replacement
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.exception\_replacer module
------------------------------------------------

.. automodule:: cosmic_ray.operators.exception_replacer
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.keyword\_replacer module
----------------------------------------------

.. automodule:: cosmic_ray.operators.keyword_replacer
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.no\_op module
-----------------------------------

.. automodule:: cosmic_ray.operators.no_op
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.number\_replacer module
---------------------------------------------

.. automodule:: cosmic_ray.operators.number_replacer
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.operator module
-------------------------------------

.. automodule:: cosmic_ray.operators.operator
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.provider module
-------------------------------------

.. automodule:: cosmic_ray.operators.provider
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.remove\_decorator module
----------------------------------------------

.. automodule:: cosmic_ray.operators.remove_decorator
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.unary\_operator\_replacement module
---------------------------------------------------------

.. automodule:: cosmic_ray.operators.unary_operator_replacement
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.util module
---------------------------------

.. automodule:: cosmic_ray.operators.util
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.operators.zero\_iteration\_for\_loop module
-------------------------------------------------------

.. automodule:: cosmic_ray.operators.zero_iteration_for_loop
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cosmic_ray.operators
   :members:
   :undoc-members:
   :show-inheritance:
